Booklets

Moda Stoq

Drawee Client
Installment 1 of 5 | Due date 01/05/12
Sale # / Payment # 00123 / 00066 | Value $14.35

Moda Stoq 24.198.774/7322-35

Drawee Client | Due date 01/05/12
Drawee's document | Drawee's phone number | Installment 1 of 5
Emission date 01/01/12 | Sale # 00123 | Payment # 00066 | Installments total $71.75 | (=) Document value $14.35
Instructions Instruction line 1 Instruction line 2 Instruction line 3 Instruction line 4 Instruction line 5 Demonstrative 1 x Banana 2 x Batata 3 x Tomate | (+) Penalty
(+) Interest
(-) Discount
(=) Total value $14.35

Moda Stoq

Drawee Client
Installment 2 of 5 | Due date 02/05/12
Sale # / Payment # 00123 / 00067 | Value $14.35

Moda Stoq 24.198.774/7322-35

Drawee Client | Due date 02/05/12
Drawee's document | Drawee's phone number | Installment 2 of 5
Emission date 01/01/12 | Sale # 00123 | Payment # 00067 | Installments total $71.75 | (=) Document value $14.35
Instructions Instruction line 1 Instruction line 2 Instruction line 3 Instruction line 4 Instruction line 5 Demonstrative 1 x Banana 2 x Batata 3 x Tomate | (+) Penalty
(+) Interest
(-) Discount
(=) Total value $14.35

Moda Stoq

Drawee Client
Installment 3 of 5 | Due date 03/05/12
Sale # / Payment # 00123 / 00068 | Value $14.35

Moda Stoq 24.198.774/7322-35

Drawee Client | Due date 03/05/12
Drawee's document | Drawee's phone number | Installment 3 of 5
Emission date 01/01/12 | Sale # 00123 | Payment # 00068 | Installments total $71.75 | (=) Document value $14.35
Instructions Instruction line 1 Instruction line 2 Instruction line 3 Instruction line 4 Instruction line 5 Demonstrative 1 x Banana 2 x Batata 3 x Tomate | (+) Penalty
(+) Interest
(-) Discount
(=) Total value $14.35

Moda Stoq

Drawee Client
Installment 4 of 5 | Due date 04/05/12
Sale # / Payment # 00123 / 00069 | Value $14.35

Moda Stoq 24.198.774/7322-35

Drawee Client | Due date 04/05/12
Drawee's document | Drawee's phone number | Installment 4 of 5
Emission date 01/01/12 | Sale # 00123 | Payment # 00069 | Installments total $71.75 | (=) Document value $14.35
Instructions Instruction line 1 Instruction line 2 Instruction line 3 Instruction line 4 Instruction line 5 Demonstrative 1 x Banana 2 x Batata 3 x Tomate | (+) Penalty
(+) Interest
(-) Discount
(=) Total value $14.35

Moda Stoq

Drawee Client
Installment 5 of 5 | Due date 05/05/12
Sale # / Payment # 00123 / 00070 | Value $14.35

Moda Stoq 24.198.774/7322-35

Drawee Client | Due date 05/05/12
Drawee's document | Drawee's phone number | Installment 5 of 5
Emission date 01/01/12 | Sale # 00123 | Payment # 00070 | Installments total $71.75 | (=) Document value $14.35
Instructions Instruction line 1 Instruction line 2 Instruction line 3 Instruction line 4 Instruction line 5 Demonstrative 1 x Banana 2 x Batata 3 x Tomate | (+) Penalty
(+) Interest
(-) Discount
(=) Total value $14.35

# Promissory Note

## Payment local

Moda Stoq - 24.198.774/7322-35
Avendia São Carlos 2333, Centro
São Carlos / SP

## Issuer

Client
Mainstreet 138, Cidade Araci
Los Angeles / Californa

Number: | 00123 / 00066
Emission date: | 01 de January de 2012
Due date: | 05 de January de 2012
Value: | $14.35

# Promissory Note

## Payment local

Moda Stoq - 24.198.774/7322-35
Avendia São Carlos 2333, Centro
São Carlos / SP

## Issuer

Client
Mainstreet 138, Cidade Araci
Los Angeles / Californa

Number: | 00123 / 00067
Emission date: | 01 de January de 2012
Due date: | 05 de February de 2012
Value: | $14.35

# Promissory Note

## Payment local

Moda Stoq - 24.198.774/7322-35
Avendia São Carlos 2333, Centro
São Carlos / SP

## Issuer

Client
Mainstreet 138, Cidade Araci
Los Angeles / Californa

Number: | 00123 / 00068
Emission date: | 01 de January de 2012
Due date: | 05 de March de 2012
Value: | $14.35

# Promissory Note

## Payment local

Moda Stoq - 24.198.774/7322-35
Avendia São Carlos 2333, Centro
São Carlos / SP

## Issuer

Client
Mainstreet 138, Cidade Araci
Los Angeles / Californa

Number: | 00123 / 00069
Emission date: | 01 de January de 2012
Due date: | 05 de April de 2012
Value: | $14.35

# Promissory Note

## Payment local

Moda Stoq - 24.198.774/7322-35
Avendia São Carlos 2333, Centro
São Carlos / SP

## Issuer

Client
Mainstreet 138, Cidade Araci
Los Angeles / Californa

Number: | 00123 / 00070
Emission date: | 01 de January de 2012
Due date: | 05 de May de 2012
Value: | $14.35